Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: src/arm64/debug-arm64.cc

Issue 207823003: Rename A64 port to ARM64 port (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: retry Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/arm64/cpu-arm64.cc ('k') | src/arm64/decoder-arm64.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/arm64/debug-arm64.cc
diff --git a/src/a64/debug-a64.cc b/src/arm64/debug-arm64.cc
similarity index 97%
rename from src/a64/debug-a64.cc
rename to src/arm64/debug-arm64.cc
index 8b901d778f0797996d22f83bf46860519bc155d2..716337f0519a4cea7bf11c6d2ecd5f695b83ed01 100644
--- a/src/a64/debug-a64.cc
+++ b/src/arm64/debug-arm64.cc
@@ -27,7 +27,7 @@
#include "v8.h"
-#if V8_TARGET_ARCH_A64
+#if V8_TARGET_ARCH_ARM64
#include "codegen.h"
#include "debug.h"
@@ -314,7 +314,7 @@ void Debug::GenerateReturnDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallFunctionStubDebugBreak(MacroAssembler* masm) {
// Register state for CallFunctionStub (from code-stubs-a64.cc).
// ----------- S t a t e -------------
// -- x1 : function
// -----------------------------------
@@ -323,7 +323,7 @@ void Debug::GenerateCallFunctionStubDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallFunctionStubRecordDebugBreak(MacroAssembler* masm) {
// Register state for CallFunctionStub (from code-stubs-a64.cc).
// ----------- S t a t e -------------
// -- x1 : function
// -- x2 : feedback array
@@ -334,7 +334,7 @@ void Debug::GenerateCallFunctionStubRecordDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallConstructStubDebugBreak(MacroAssembler* masm) {
// Calling convention for CallConstructStub (from code-stubs-a64.cc).
// ----------- S t a t e -------------
// -- x0 : number of arguments (not smi)
// -- x1 : constructor function
@@ -344,7 +344,7 @@ void Debug::GenerateCallConstructStubDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallConstructStubRecordDebugBreak(MacroAssembler* masm) {
// Calling convention for CallConstructStub (from code-stubs-a64.cc).
// ----------- S t a t e -------------
// -- x0 : number of arguments (not smi)
// -- x1 : constructor function
@@ -376,12 +376,12 @@ void Debug::GenerateSlotDebugBreak(MacroAssembler* masm) {
void Debug::GeneratePlainReturnLiveEdit(MacroAssembler* masm) {
- masm->Abort(kLiveEditFrameDroppingIsNotSupportedOnA64);
+ masm->Abort(kLiveEditFrameDroppingIsNotSupportedOnARM64);
}
void Debug::GenerateFrameDropperLiveEdit(MacroAssembler* masm) {
- masm->Abort(kLiveEditFrameDroppingIsNotSupportedOnA64);
+ masm->Abort(kLiveEditFrameDroppingIsNotSupportedOnARM64);
}
const bool Debug::kFrameDropperSupported = false;
@@ -390,4 +390,4 @@ const bool Debug::kFrameDropperSupported = false;
} } // namespace v8::internal
-#endif // V8_TARGET_ARCH_A64
+#endif // V8_TARGET_ARCH_ARM64
« no previous file with comments | « src/arm64/cpu-arm64.cc ('k') | src/arm64/decoder-arm64.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -314,7 +314,7 @@ void Debug::GenerateReturnDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallFunctionStubDebugBreak(MacroAssembler* masm) {
- // Register state for CallFunctionStub (from code-stubs-a64.cc).
+ // Register state for CallFunctionStub (from code-stubs-arm64.cc).
// ----------- S t a t e -------------
// -- x1 : function
@@ -323,7 +323,7 @@ void Debug::GenerateCallFunctionStubDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallFunctionStubRecordDebugBreak(MacroAssembler* masm) {
- // Register state for CallFunctionStub (from code-stubs-a64.cc).
+ // Register state for CallFunctionStub (from code-stubs-arm64.cc).
// ----------- S t a t e -------------
// -- x1 : function
@@ -334,7 +334,7 @@ void Debug::GenerateCallFunctionStubRecordDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallConstructStubDebugBreak(MacroAssembler* masm) {
- // Calling convention for CallConstructStub (from code-stubs-a64.cc).
+ // Calling convention for CallConstructStub (from code-stubs-arm64.cc).
// ----------- S t a t e -------------
// -- x0 : number of arguments (not smi)
@@ -344,7 +344,7 @@ void Debug::GenerateCallConstructStubDebugBreak(MacroAssembler* masm) {
void Debug::GenerateCallConstructStubRecordDebugBreak(MacroAssembler* masm) {
- // Calling convention for CallConstructStub (from code-stubs-a64.cc).
+ // Calling convention for CallConstructStub (from code-stubs-arm64.cc).
// ----------- S t a t e -------------
// -- x0 : number of arguments (not smi)
This is Rietveld 408576698